@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2014 Snowplow Analytics Ltd. All rights reserved.
+# Copyright (c) 2013-2021 Snowplow Analytics Ltd. All rights reserved.
 #
 # This program is licensed to you under the Apache License Version 2.0,
 # and you may not use this file except in compliance with the Apache License Version 2.0.
@@ -9,16 +9,16 @@
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the Apache License Version 2.0 for the specific language governing permissions and limitations there under.
 
-# Author::    Alex Dean, Fred Blundun (mailto:snowplow-user@googlegroups.com)
-# Copyright:: Copyright (c) 2013-2014 Snowplow Analytics Ltd
+# Author:: Snowplow Analytics Ltd
+# Copyright:: Copyright (c) 2013-2021 Snowplow Analytics Ltd
 # License::   Apache License Version 2.0
 
-require 'snowplow-tracker/contracts.rb'
+
 require 'snowplow-tracker/version.rb'
 require 'snowplow-tracker/self_describing_json.rb'
 require 'snowplow-tracker/payload.rb'
 require 'snowplow-tracker/subject.rb'
+require 'snowplow-tracker/page.rb'
 require 'snowplow-tracker/emitters.rb'
 require 'snowplow-tracker/timestamp.rb'
 require 'snowplow-tracker/tracker.rb'
-
